Quasar widget for trame
===========================================================================

Trame bundle for the Quasar Vue library.

-----------------------------------------------------------

trame-quasar is made available under the MIT License. For more details, see `LICENSE <https://github.com/Kitware/trame-quasar/blob/master/LICENSE>`_
This license has been chosen to match the one use by `Quasar <https://github.com/quasarframework/quasar/blob/dev/LICENSE>`_ which is the core of that library possible.


Community
-----------------------------------------------------------

`Trame <https://kitware.github.io/trame/>`_ | `Discussions <https://github.com/Kitware/trame/discussions>`_ | `Issues <https://github.com/Kitware/trame/issues>`_ | `RoadMap <https://github.com/Kitware/trame/projects/1>`_ | `Contact Us <https://www.kitware.com/contact-us/>`_

.. image:: https://zenodo.org/badge/410108340.svg
    :target: https://zenodo.org/badge/latestdoi/410108340


Enjoying trame?
-----------------------------------------------------------

Share your experience `with a testimonial <https://github.com/Kitware/trame/issues/18>`_ or `with a brand approval <https://github.com/Kitware/trame/issues/19>`_.
